@@ -1,8 +1,8 @@
 
 # data will need to be an unmarkedMultFrame
 gmultmix <- function(lambdaformula, phiformula, pformula, data,
-    mixture=c('P', 'NB'), K, starts, method = "BFGS", se = TRUE, 
-    engine=c("C","R"), ...)
+    mixture=c('P', 'NB'), K, starts, method = "BFGS", se = TRUE,
+    engine=c("C","R"), threads=1, ...)
 {
 if(!is(data, "unmarkedFrameGMM"))
     stop("Data is not of class unmarkedFrameGMM.")
@@ -13,6 +13,7 @@ mixture <- match.arg(mixture)
 
 formlist <- list(lambdaformula = lambdaformula, phiformula = phiformula,
     pformula = pformula)
+check_no_support(formlist)
 form <- as.formula(paste(unlist(formlist), collapse=" "))
 D <- getDesign(data, formula = form)
 
@@ -97,7 +98,7 @@ nll_R <- function(pars) {
 
     for(t in 1:T) cp[,t,1:R] <- do.call(piFun, list(p[,t,]))
     cp[,,1:R] <- cp[,,1:R] * phi
-    cp[,, 1:R][is.na(y)]<- NA   # andy added 5/29 
+    cp[,, 1:R][is.na(y)]<- NA   # andy added 5/29
     cp[,,R+1] <- 1 - apply(cp[,,1:R,drop=FALSE], 1:2, sum, na.rm=TRUE)
 
     switch(mixture,
@@ -121,15 +122,6 @@ nll_R <- function(pars) {
     -sum(log(ll))
     }
 
-nll_C <- function(params) {
-  .Call("nll_gmultmix",
-        params,mixture, piFun,
-        Xlam, Xlam.offset, Xphi, Xphi.offset, Xdet, Xdet.offset,  
-        k,lfac.k, lfac.kmyt,kmytC,
-        y_long, naflag_long, fin,
-        nP,nLP,nPP,nDP,
-        PACKAGE = "unmarked")
-}
 
 if(engine=="R"){
   nll <- nll_R
@@ -139,10 +131,18 @@ if(engine=="R"){
     as.vector(t(out))
   }
   y_long <- long_format(y)
-  naflag_long <- long_format(naflag)
   kmytC <- kmyt
   kmytC[which(is.na(kmyt))] <- 0
-  nll <- nll_C
+
+  mixture_code <- switch(mixture, P={1}, NB={2})
+  n_param <- c(nLP, nPP, nDP, mixture=="NB")
+  Kmin <- apply(yt, 1, max, na.rm=TRUE)
+
+  nll <- function(params) {
+    nll_gmultmix(params, n_param, y_long, mixture_code, piFun, Xlam, Xlam.offset,
+                 Xphi, Xphi.offset, Xdet, Xdet.offset, k, lfac.k, lfac.kmyt,
+                 kmytC, Kmin, threads)
+  }
 
   if(!piFun%in%c('doublePiFun','removalPiFun','depDoublePiFun')){
     warning("Custom pi functions are not supported by C engine. Using R engine instead.")
