@@ -153,7 +153,7 @@ multmixOpen <- function(lambdaformula, gammaformula, omegaformula, pformula,
   #finding all unique likelihood transitions
   I <- cbind(rep(k, times=lk), rep(k, each=lk))
   I1 <- I[I[,1] <= I[,2],]
-  lik_trans <- .Call("get_lik_trans", I, I1, PACKAGE="unmarked")
+  lik_trans <- get_lik_trans(I, I1)
 
   beta_ind <- matrix(NA, 6, 2)
   beta_ind[1,] <- c(1, nAP) #Abundance
@@ -171,7 +171,7 @@ multmixOpen <- function(lambdaformula, gammaformula, omegaformula, pformula,
   yperm <- aperm(yperm, c(3,2,1)) # fix asan problem
 
   nll <- function(parms) {
-    .Call("nll_multmixOpen",
+    nll_multmixOpen(
           yperm, yt,
           D$Xlam, D$Xgam, D$Xom, D$Xp, D$Xiota,
           parms, beta_ind - 1,
@@ -180,8 +180,8 @@ multmixOpen <- function(lambdaformula, gammaformula, omegaformula, pformula,
           lk, mixture, first - 1, last - 1, first1 - 1, M, T, J, R,
           D$delta, dynamics, fix, D$go.dims, immigration,
           I, I1, lik_trans$Ib, lik_trans$Ip,
-          piFun, lfac.k, kmyt, lfac.kmyt, fin,
-          PACKAGE = "unmarked")
+          piFun, lfac.k, kmyt, lfac.kmyt, fin
+          )
   }
 
   if(missing(starts)){
