@@ -1,31 +1,40 @@
-### R code from vignette source 'cap-recap.Rnw'
+## ----echo=FALSE---------------------------------------------------------------
+options(rmarkdown.html_vignette.check_title = FALSE)
 
-###################################################
-### code chunk number 1: cap-recap.Rnw:1-4
-###################################################
-options(width=70)
-options(continue=" ")
-library(tools)
+## ---- echo=FALSE--------------------------------------------------------------
+tab <- data.frame(
+  id = c("GB","YR","RO","PP","GY","PR"),
+  site = c(rep("A",4), "B", "B"),
+  cap = c("101","101","111","100","100","010")
+)
+names(tab) <- c("Animal ID", "Site", "Capture history")
 
+knitr::kable(tab, align="lcc",
+  caption="Table 1. Capture-recapture data for 6 individuals sampled on 3 occasions"
+)
 
-###################################################
-### code chunk number 2: cap-recap.Rnw:214-216
-###################################################
+## ---- echo=FALSE--------------------------------------------------------------
+tab2 <- data.frame(
+  Site=c("A","B","C","D"),
+  eh100=c(1,1,0,0), eh010=c(0,1,0,0), eh001=c(0,0,0,0),
+  eh110=c(0,0,0,0), eh011=c(0,0,0,0), eh101=c(2,0,0,0),
+  eh111=c(1,0,0,0))
+names(tab2) <- c("Site", "100","010","001","110","011","101","111")
+
+knitr::kable(tab2, align="lccccccc",
+  caption="Table 2. Capture-recapture data from Table 1 in the format required by unmarked")
+
+## -----------------------------------------------------------------------------
 alfl <- read.csv(system.file("csv", "alfl.csv", package="unmarked"))
 head(alfl, 5)
 
+## -----------------------------------------------------------------------------
 
-###################################################
-### code chunk number 3: cap-recap.Rnw:227-230
-###################################################
 alfl.covs <- read.csv(system.file("csv", "alflCovs.csv",
     package="unmarked"), row.names=1)
 head(alfl.covs)
 
-
-###################################################
-### code chunk number 4: cap-recap.Rnw:244-250
-###################################################
+## -----------------------------------------------------------------------------
 alfl$captureHistory <- paste(alfl$interval1, alfl$interval2, alfl$interval3, sep="")
 alfl$captureHistory <- factor(alfl$captureHistory,
     levels=c("001", "010", "011", "100", "101", "110", "111"))
@@ -33,18 +42,12 @@ alfl$captureHistory <- factor(alfl$captureHistory,
 #levels(alfl$id) <- rownames(alfl.covs)
 alfl$id <- factor(alfl$id, levels=rownames(alfl.covs))
 
-
-###################################################
-### code chunk number 5: cap-recap.Rnw:262-265
-###################################################
+## -----------------------------------------------------------------------------
 alfl.v1 <- alfl[alfl$survey==1,]
 alfl.H1 <- table(alfl.v1$id, alfl.v1$captureHistory)
 head(alfl.H1, 5)
 
-
-###################################################
-### code chunk number 6: cap-recap.Rnw:299-311
-###################################################
+## -----------------------------------------------------------------------------
 crPiFun <- function(p) {
     p1 <- p[,1]
     p2 <- p[,2]
@@ -58,24 +61,15 @@ crPiFun <- function(p) {
           "111" = p1     * p2     * p3)
 }
 
-
-###################################################
-### code chunk number 7: cap-recap.Rnw:320-323
-###################################################
+## -----------------------------------------------------------------------------
 p <- matrix(0.4, 2, 3)
 crPiFun(p)
 rowSums(crPiFun(p))
 
-
-###################################################
-### code chunk number 8: cap-recap.Rnw:342-343
-###################################################
+## -----------------------------------------------------------------------------
 o2y <- matrix(1, 3, 7)
 
-
-###################################################
-### code chunk number 9: cap-recap.Rnw:352-359
-###################################################
+## -----------------------------------------------------------------------------
 library(unmarked)
 intervalMat <- matrix(c('1','2','3'), 50, 3, byrow=TRUE)
 class(alfl.H1) <- "matrix"
@@ -84,24 +78,15 @@ umf.cr1 <- unmarkedFrameMPois(y=alfl.H1,
     obsCovs=list(interval=intervalMat),
     obsToY=o2y, piFun="crPiFun")
 
+## -----------------------------------------------------------------------------
+M0 <- multinomPois(~1 ~1, umf.cr1, engine="R")
+Mt <- multinomPois(~interval-1 ~1, umf.cr1, engine="R")
+Mx <- multinomPois(~time.1 ~1, umf.cr1, engine="R")
 
-###################################################
-### code chunk number 10: cap-recap.Rnw:376-379
-###################################################
-M0 <- multinomPois(~1 ~1, umf.cr1)
-Mt <- multinomPois(~interval-1 ~1, umf.cr1)
-Mx <- multinomPois(~time.1 ~1, umf.cr1)
+## -----------------------------------------------------------------------------
+(M0.woody <- multinomPois(~1 ~woody, umf.cr1, engine="R"))
 
-
-###################################################
-### code chunk number 11: cap-recap.Rnw:388-389
-###################################################
-(M0.woody <- multinomPois(~1 ~woody, umf.cr1))
-
-
-###################################################
-### code chunk number 12: woody
-###################################################
+## ---- fig.width=5, fig.height=5-----------------------------------------------
 nd <- data.frame(woody=seq(0, 0.8, length=50))
 E.abundance <- predict(M0.woody, type="state", newdata=nd, appendData=TRUE)
 plot(Predicted ~ woody, E.abundance, type="l", ylim=c(0, 6),
@@ -109,22 +94,13 @@ plot(Predicted ~ woody, E.abundance, type="l", ylim=c(0, 6),
 lines(lower ~ woody, E.abundance, col=gray(0.7))
 lines(upper ~ woody, E.abundance, col=gray(0.7))
 
-
-###################################################
-### code chunk number 13: cap-recap.Rnw:418-419
-###################################################
+## -----------------------------------------------------------------------------
 backTransform(M0.woody, type="det")
 
-
-###################################################
-### code chunk number 14: cap-recap.Rnw:427-428
-###################################################
+## -----------------------------------------------------------------------------
 round(getP(M0.woody), 2)[1,]
 
-
-###################################################
-### code chunk number 15: cap-recap.Rnw:455-466
-###################################################
+## -----------------------------------------------------------------------------
 crPiFun.Mb <- function(p) { # p should have 3 columns
     pNaive <- p[,1]
     pWise <- p[,3]
@@ -137,33 +113,21 @@ crPiFun.Mb <- function(p) { # p should have 3 columns
           "111" = pNaive     * pWise      * pWise)
 }
 
-
-###################################################
-### code chunk number 16: cap-recap.Rnw:479-485
-###################################################
+## -----------------------------------------------------------------------------
 behavior <- matrix(c('Naive','Naive','Wise'), 50, 3, byrow=TRUE)
 umf.cr1Mb <- unmarkedFrameMPois(y=alfl.H1,
     siteCovs=alfl.covs[,c("woody", "struct", "time.1")],
     obsCovs=list(behavior=behavior),
     obsToY=o2y, piFun="crPiFun.Mb")
-M0 <- multinomPois(~1 ~1, umf.cr1Mb)
+M0 <- multinomPois(~1 ~1, umf.cr1Mb, engine="R")
 
+## -----------------------------------------------------------------------------
+(Mb <- multinomPois(~behavior-1 ~1, umf.cr1Mb, engine="R"))
 
-###################################################
-### code chunk number 17: cap-recap.Rnw:490-491
-###################################################
-(Mb <- multinomPois(~behavior-1 ~1, umf.cr1Mb))
-
-
-###################################################
-### code chunk number 18: cap-recap.Rnw:497-498
-###################################################
+## -----------------------------------------------------------------------------
 plogis(confint(Mb, type="det", method="profile"))
 
-
-###################################################
-### code chunk number 19: cap-recap.Rnw:545-577
-###################################################
+## -----------------------------------------------------------------------------
 MhPiFun <- function(p) {
 mu <- qlogis(p[,1]) # logit(p)
 sig <- exp(qlogis(p[1,2]))
@@ -197,10 +161,15 @@ for(i in 1:M) {
 return(il)
 }
 
+## ---- eval=FALSE--------------------------------------------------------------
+#  parID <- matrix(c('p','sig','sig'), 50, 3, byrow=TRUE)
+#  umf.cr2 <- unmarkedFrameMPois(y=alfl.H1,
+#    siteCovs=alfl.covs[,c("woody", "struct", "time.1")],
+#    obsCovs=list(parID=parID),
+#    obsToY=o2y, piFun="MhPiFun")
+#  multinomPois(~parID-1 ~woody, umf.cr2)
 
-###################################################
-### code chunk number 20: cap-recap.Rnw:695-704
-###################################################
+## -----------------------------------------------------------------------------
 alfl.H <- table(alfl$id, alfl$captureHistory, alfl$survey)
 alfl.Hmat <- cbind(alfl.H[,,1], alfl.H[,,2], alfl.H[,,3])
 nVisits <- 3
@@ -211,10 +180,6 @@ umf.cr <- unmarkedFrameGMM(y=alfl.Hmat,
     obsCovs=list(interval=cbind(intervalMat,intervalMat,intervalMat)),
     obsToY=o2yGMM, piFun="crPiFun", numPrimary=nVisits)
 
-
-###################################################
-### code chunk number 21: cap-recap.Rnw:723-724
-###################################################
-(fm1 <- gmultmix(~woody, ~1, ~time+date, umf.cr))
-
+## -----------------------------------------------------------------------------
+(fm1 <- gmultmix(~woody, ~1, ~time+date, umf.cr, engine="R"))
 
